// **** BEGIN LICENSE BLOCK ****
//   Copyright(c) 2009 MATSUZAWA Jiro
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the Free Software
//   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA
//   02110-1301, USA.  */
// **** END LICENSE BLOCK ****

var rencon;
if (!rencon) {
    rencon = {};
} else if (typeof rencon != "object") {
    throw new Error("Rencon cannot run");
}

rencon.settings = {

    conf : null,

    saveConfig : function()
    {
        var configFile;
        var howToSave;
        var saveDir;
        try {
            conf = new rencon.Config();

            rencon.settings.saveSeparator();
            rencon.settings.saveHeader();
            rencon.settings.saveItemOrders();
            rencon.settings.saveHowToSave();
            rencon.settings.saveEncoding();

            conf.write(rencon.SettingsConf.getConfigName());
        } catch (e) {
            ;
        } finally {
            conf = null;
        }
    },


    reflectConfig : function()
    {
        conf = new rencon.Config();
        try {
            conf.read(rencon.SettingsConf.getConfigName());
            rencon.settings.reflectSeparator();
            rencon.settings.reflectHeader();
            rencon.settings.reflectItemOrders();
            rencon.settings.reflectHowToSave();
            rencon.settings.reflectEncoding();
        } catch(e) {
            ;
        } finally {
            conf = null;
        }
    },


    saveSeparator : function()
    {
        var radioGroup = document.getElementById("separatorGroup");
        var actRadio = radioGroup.selectedItem;
        if (actRadio.id != "separatorOther") {
            conf.setValue("separator", actRadio.value);
            return;
        }
        var text = document.getElementById("otherSeparatorText");
        if (text.value == "") {
            conf.setValue("separator", "\\t");
            return;
        }
        conf.setValue("otherSeparator", text.value);
    },


    saveHeader : function()
    {
        var header = document.getElementById("putHeader");
        var val = "0";
        if (header.checked) {
            val = "1";
        }
        conf.setValue("header", val);
    },


    saveItemOrders : function()
    {
        conf.setValue("titleOrder", rencon.settings.getMenuItemValue("titleOrder"));
        conf.setValue("creatorOrder", rencon.settings.getMenuItemValue("creatorOrder"));
        conf.setValue("journalOrder", rencon.settings.getMenuItemValue("journalOrder"));
        conf.setValue("volOrder", rencon.settings.getMenuItemValue("volOrder"));
        conf.setValue("publisherOrder", rencon.settings.getMenuItemValue("publisherOrder"));
        conf.setValue("pubDateOrder", rencon.settings.getMenuItemValue("pubDateOrder"));
        conf.setValue("pagesOrder", rencon.settings.getMenuItemValue("pagesOrder"));
        conf.setValue("urlOrder", rencon.settings.getMenuItemValue("urlOrder"));
    },


    saveHowToSave : function()
    {
        var how = rencon.settings.getHowToSave();
        conf.setValue("howToSave", how);
        if (how == "userDir") {
            saveDir = rencon.settings.getSaveDir();
            if (saveDir != "") {
                conf.setValue("saveDir", saveDir);
            } else {
                conf.setValue("howToSave", "ask");
            }
        }
    },


    saveEncoding : function()
    {
        conf.setValue("encoding", rencon.settings.getMenuItemValue("encoding"));
    },


    getMenuItemValue : function(
        id
        )
    {
        var list = document.getElementById(id);
        var actItem = list.selectedItem;
        return actItem.value;
    },


    getHowToSave : function()
    {
        var group = document.getElementById("howToSave");
        return group.selectedItem.value;
    },


    getSaveDir : function()
    {
        var filefield = document.getElementById("saveDir");
        return filefield.label;
    },


    reflectSeparator : function()
    {
        var radioGroup = document.getElementById("separatorGroup");
        var sep = conf.getValue("separator");
        var otherText;
        switch (sep) {
        case "\\t":
            return;
        case ",":
            radioGroup.selectedItem = document.getElementById("separatorComma");
            return;
        case ":":
            radioGroup.selectedItem = document.getElementById("separatorColon");
            return;
        case ";":
            radioGroup.selectedItem = document.getElementById("separatorSemiColon");
            return;
        case " ":
            radioGroup.selectedItem = document.getElementById("separatorSpace");
            return;
        default:
            break;
        }
        sep = conf.getValue("otherSeparator");
        if (!sep) {
            return;
        }
        radioGroup.selectedItem = document.getElementById("separatorOther");
        otherText = document.getElementById("otherSeparatorText");
        otherText.disabled = false;
        otherText.value = sep;
    },


    reflectHeader: function()
    {
        if (conf.getValue("header") == "0") {
            header = document.getElementById("putHeader");
            header.checked = false;
        }
    },


    reflectItemOrders : function()
    {
        rencon.settings.reflectItemOrder("title");
        rencon.settings.reflectItemOrder("creator");
        rencon.settings.reflectItemOrder("journal");
        rencon.settings.reflectItemOrder("vol");
        rencon.settings.reflectItemOrder("publisher");
        rencon.settings.reflectItemOrder("pubDate");
        rencon.settings.reflectItemOrder("pages");
        rencon.settings.reflectItemOrder("url");
    },


    reflectItemOrder : function(
        item
        )
    {
        var list;
        var validOrder = /[1-8]/;
        var itemOrder = conf.getValue(item + "Order");
        if (itemOrder && validOrder.test(itemOrder)) {
            list = document.getElementById(item + "Order");
            list.selectedItem = document.getElementById(item + itemOrder);
        }
    },


    reflectHowToSave : function()
    {
        var group = document.getElementById("howToSave");
        var how = conf.getValue("howToSave");
        var filefield;
        var dir;
        var file;

        if (how == "userDir" &&
            (dir = conf.getValue("saveDir")) != "")
        {
            file =  Components.classes["@mozilla.org/file/local;1"]
                        .createInstance(Components.interfaces.nsILocalFile);
            if (!file) {
                throw new Error("cannot open " + file);
            }
            file.initWithPath(dir);
            if (!file.exists()) {
                throw new Error(file.path + " is not found");
            }

            group.selectedItem = document.getElementById("saveTo");
            filefield = document.getElementById("saveDir");
            filefield.file = file;
            filefield.label = dir;
            rencon.settings.chooseDirOn();
            return;
        }
        group.selectedItem = document.getElementById("alwaysAsk");
    },


    reflectEncoding : function()
    {
        var list = document.getElementById("encoding");
        var encoding = conf.getValue("encoding");
        switch (encoding) {
        case "Shift_JIS":
            list.selectedItem = document.getElementById("encoding_Shift_JIS");
            return;
        case "EUC-JP":
            list.selectedItem = document.getElementById("encoding_EUC-JP");
            return;
        case "ISO-2022-JP":
            list.selectedItem = document.getElementById("encoding_ISO-2022-JP");
            return;
        case "ISO-8859-1":
            list.selectedItem = document.getElementById("encoding_ISO-8859-1");
            return;
        case "ISO-8859-15":
            list.selectedItem = document.getElementById("encoding_ISO-8859-15");
            return;
        case "ISO-8859-2":
            list.selectedItem = document.getElementById("encoding_ISO-8859-2");
            return;
        case "ISO-8859-16":
            list.selectedItem = document.getElementById("encoding_ISO-8859-16");
            return;
        default:
            return;
        }
    },


    separatorOtherOn : function()
    {
        var sepTextNode = document.getElementById("otherSeparatorText");
        sepTextNode.disabled = false;
    },


    separatorOtherOff : function()
    {
        var sepTextNode = document.getElementById("otherSeparatorText");
        sepTextNode.disabled = true;
    },


    chooseDirOn : function()
    {
        var button = document.getElementById("chooseDirButton");
        button.disabled = false;
    },


    chooseDirOff : function()
    {
        var button = document.getElementById("chooseDirButton");
        button.disabled = true;
    },


    chooseDir : function()
    {
        var picker;
        var dir;
        var filefield;
        picker = Components.classes["@mozilla.org/filepicker;1"]
                        .createInstance(Components.interfaces.nsIFilePicker);
        picker.init(window, "フォルダを選択", picker.modeGetFolder);
        if (picker.show() != 0) {
            return;
        }
        dir = picker.file.path;
        filefield = document.getElementById("saveDir");
        filefield.file = picker.file;
        filefield.label = dir;
    },

};
